PayUOLWParamKeys class
Customer/Merchant params keys for SDK initialization
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- customerMobile → const String
- isProduction → const String
- kycRedirectionUrl → const String
- merchantKey → const String
- merchantLogoName → const String
- merchantSupportEmail → const String
- payuReferrenceId → const String
- primaryColor → const String
- termsAndConditionsURL → const String